@@ -1,4 +1,4 @@
-﻿define(['jQuery'], function ($) {
+﻿define(['jQuery', 'apphost', 'cardStyle'], function ($, appHost) {
 
     function changeCollectionType(page, virtualFolder) {
 
@@ -103,10 +103,16 @@
             ironIcon: 'videocam'
         });
 
+        menuItems.push({
+            name: Globalize.translate('ButtonEditImages'),
+            id: 'editimages',
+            ironIcon: 'photo'
+        });
+
         menuItems.push({
             name: Globalize.translate('ButtonManageFolders'),
             id: 'edit',
-            ironIcon: 'folder-open'
+            ironIcon: 'folder_open'
         });
 
         menuItems.push({
@@ -118,7 +124,7 @@
         menuItems.push({
             name: Globalize.translate('ButtonRename'),
             id: 'rename',
-            ironIcon: 'mode-edit'
+            ironIcon: 'mode_edit'
         });
 
         require(['actionsheet'], function (actionsheet) {
@@ -136,6 +142,9 @@
                         case 'edit':
                             editVirtualFolder(page, virtualFolder);
                             break;
+                        case 'editimages':
+                            editImages(page, virtualFolder);
+                            break;
                         case 'rename':
                             renameVirtualFolder(page, virtualFolder);
                             break;
@@ -171,7 +180,7 @@
 
         virtualFolders.push({
             Name: Globalize.translate('ButtonAddMediaLibrary'),
-            icon: 'add-circle',
+            icon: 'add_circle',
             Locations: [],
             showType: false,
             showLocations: false,
@@ -188,6 +197,8 @@
 
         var divVirtualFolders = page.querySelector('#divVirtualFolders');
         divVirtualFolders.innerHTML = html;
+        divVirtualFolders.classList.add('itemsContainer');
+        divVirtualFolders.classList.add('vertical-wrap');
 
         $('.btnCardMenu', divVirtualFolders).on('click', function () {
             showCardMenu(page, this, virtualFolders);
@@ -206,21 +217,24 @@
                 return;
             }
 
-            require(['components/imageeditor/imageeditor'], function (ImageEditor) {
-
-                ImageEditor.show(virtualFolder.ItemId, {
-                    theme: 'a'
-                }).then(function (hasChanged) {
-                    if (hasChanged) {
-                        reloadLibrary(page);
-                    }
-                });
-            });
+            editVirtualFolder(page, virtualFolder);
         });
 
         Dashboard.hideLoadingMsg();
     }
 
+    function editImages(page, virtualFolder) {
+
+        require(['components/imageeditor/imageeditor'], function (ImageEditor) {
+
+            ImageEditor.show(virtualFolder.ItemId, {
+                theme: 'a'
+            }).then(function () {
+                reloadLibrary(page);
+            });
+        });
+    }
+
     function getCollectionTypeOptions() {
 
         return [
@@ -243,23 +257,23 @@
 
         switch (type) {
             case "movies":
-                return "local-movies";
+                return "local_movies";
             case "music":
-                return "library-music";
+                return "library_music";
             case "photos":
                 return "photo";
             case "livetv":
-                return "live-tv";
+                return "live_tv";
             case "tvshows":
-                return "live-tv";
+                return "live_tv";
             case "games":
                 return "folder";
             case "trailers":
-                return "local-movies";
+                return "local_movies";
             case "homevideos":
-                return "video-library";
+                return "video_library";
             case "musicvideos":
-                return "video-library";
+                return "video_library";
             case "books":
                 return "folder";
             case "channels":
@@ -281,7 +295,7 @@
             style += "min-width:33.3%;";
         }
 
-        html += '<div class="card backdropCard" style="' + style + '" data-index="' + index + '">';
+        html += '<div class="card backdropCard scalableCard" style="' + style + '" data-index="' + index + '">';
 
         html += '<div class="cardBox visualCardBox">';
         html += '<div class="cardScalable">';
@@ -298,41 +312,41 @@
         }
 
         if (imgUrl) {
-            html += '<div class="cardImage editLibrary" style="cursor:pointer;background-image:url(\'' + imgUrl + '\');"></div>';
+            html += '<div class="cardImageContainer editLibrary" style="cursor:pointer;background-image:url(\'' + imgUrl + '\');"></div>';
         } else if (!virtualFolder.showNameWithIcon) {
-            html += '<div class="cardImage editLibrary iconCardImage" style="cursor:pointer;">';
-            html += '<iron-icon icon="' + (virtualFolder.icon || getIcon(virtualFolder.CollectionType)) + '"></iron-icon>';
+            html += '<div class="cardImageContainer editLibrary" style="cursor:pointer;">';
+            html += '<i class="cardImageIcon md-icon" style="color:#444;">' + (virtualFolder.icon || getIcon(virtualFolder.CollectionType)) + '</i>';
 
             html += '</div>';
         }
 
+        if (!imgUrl && virtualFolder.showNameWithIcon) {
+            html += '<h1 class="cardImageContainer addLibrary" style="position:absolute;top:0;left:0;right:0;bottom:0;cursor:pointer;flex-direction:column;">';
+
+            html += '<i class="cardImageIcon md-icon" style="font-size:400%;color:#888;height:auto;width:auto;">' + (virtualFolder.icon || getIcon(virtualFolder.CollectionType)) + '</i>';
+
+            if (virtualFolder.showNameWithIcon) {
+                html += '<div style="margin:1.5em 0;position:width:100%;font-weight:500;color:#444;">';
+                html += virtualFolder.Name;
+                html += "</div>";
+            }
+
+            html += '</h1>';
+        }
+
         // cardContent
         html += "</div>";
 
         // cardScalable
         html += "</div>";
 
-        if (!imgUrl && virtualFolder.showNameWithIcon) {
-            html += '<h1 class="cardImage iconCardImage addLibrary" style="position:absolute;top:0;left:0;right:0;bottom:0;cursor:pointer;">';
-
-            html += '<div>';
-            html += '<iron-icon icon="' + (virtualFolder.icon || getIcon(virtualFolder.CollectionType)) + '" style="width:45%;height:45%;color:#888;"></iron-icon>';
-
-            if (virtualFolder.showNameWithIcon) {
-                html += '<div style="margin:1.5em 0;position:width:100%;font-weight:500;color:#444;">';
-                html += virtualFolder.Name;
-                html += "</div>";
-            }
-            html += "</div>";
-
-            html += '</h1>';
-        }
-
         html += '<div class="cardFooter">';
 
         if (virtualFolder.showMenu !== false) {
-            html += '<div class="cardText" style="text-align:right; float:right;padding-top:5px;">';
-            html += '<paper-icon-button icon="' + AppInfo.moreIcon + '" class="btnCardMenu"></paper-icon-button>';
+            var moreIcon = appHost.moreIcon == 'dots-horiz' ? '&#xE5D3;' : '&#xE5D4;';
+
+            html += '<div style="text-align:right; float:right;padding-top:5px;">';
+            html += '<button type="button" is="paper-icon-button-light" class="btnCardMenu autoSize"><i class="md-icon">' + moreIcon + '</i></button>';
             html += "</div>";
         }
 
@@ -438,6 +452,27 @@
             });
         }
     };
+
+    function getTabs() {
+        return [
+        {
+            href: 'library.html',
+            name: Globalize.translate('TabFolders')
+        },
+         {
+             href: 'librarydisplay.html',
+             name: Globalize.translate('TabDisplay')
+         },
+         {
+             href: 'librarypathmapping.html',
+             name: Globalize.translate('TabPathSubstitution')
+         },
+         {
+             href: 'librarysettings.html',
+             name: Globalize.translate('TabAdvanced')
+         }];
+    }
+
     pageClassOn('pageshow', "mediaLibraryPage", function () {
 
         var page = this;
@@ -447,6 +482,7 @@
 
     pageIdOn('pageshow', "mediaLibraryPage", function () {
 
+        LibraryMenu.setTabs('librarysetup', 0, getTabs);
         var page = this;
 
         // on here
